from apadata.modules.evaluators.language_frequency_evaluator_module import (
    LanguageFrequencyEvaluatorModule,
)
from apadata.pipelines.pipeline_context import PipelineContext


def test_language_frequency_evaluator_module():
    payload = {
        "keyword": "Consulting",
        "language": "en",
    }
    context = PipelineContext(payload=payload)
    module = LanguageFrequencyEvaluatorModule()
    module.run(context)
    assert round(context.search_field("language_frequency_score"), 4) == 0.0
